
;This version (V.4.0.1.) has some edited comments and more thorough commenting of the setup section. Also, there is now more infromation
;in the info tab above. 
;I have them delete the core from their list in order to keep it running quickly. 
;Earlier versions have the patches tracking how many cores have been dropped on them
;and the volume of those cores. 
globals [odometer meantravel sources distances travel sd lcores workperformed mobilework sedwork expectedwork]
patches-own [cores source? base? dist close? ]
turtles-own [forager? temp? pack var target  
    cond1 cond2 cond3 cond4 cond5  mpack]

to setup
  clear-all
  set distances []                                        ;Establishes a list to which each patch will add its distance to the home base later on. 
  ask patches [set cores [] ]                             ;Sets archaeology as blank. this is a list of cores, the values are a measure of relative size
 
  if rm-dist = 1                                          ;In this condition, some number of randomly selected patches are turned into raw material sources.    
 [ ask n-of nofsources patches [set pcolor white set source? true ]]
 
  if rm-dist = 2                                          ;In this condition, some number of randomly selected patches WITHIN a given radius of the home base are turned into raw material sources
   [ask patch 0 0 [let closepatches patches in-radius radius
   ask n-of nofsources closepatches [set pcolor white set source? true]]]
 
 
  if rm-dist = 3                                          ;In this condition, some number of randomly selected patches OUTSIDE a given radius of the home base are turned into raw material sources
   [ask patches [set close? false] 
    ask patch 0 0 [let closepatches patches in-radius radius
    ask closepatches [set close? true]]
    ask n-of nofsources patches [if close? = false [set pcolor white set source? true]]]  
      
  set sources patches with [pcolor = white]               ;Establishes patches selected above as raw material sources. 
  
  ask patch 0 0 [set pcolor red 
                 set base? true
                 set cores lput 40 cores]                 ;This establishes the home base. 
  
    
  crt nofturtles       
      [setxy 0 0 
        set size 3
        set color blue
        set forager?  true
        set temp? false
        set pack []]                                      ;Establishes the list to which raw material cobbles/cores are added and from which they are subtracted
      
  ask n-of (% * nofturtles) turtles                       ;Establishes the number of turtles who will live as camp dwellers. 
       [set color gray
        set forager? false
        set pack []]                                      ;Camp dwellers have their own packs.   
       
   ask turtles [initialize]                               ;This puts all the turtles on the same page, in preparation for their first runs. 
   ask patches with [source? = true]         
        [set dist distance patch 0 0 
         set distances lput dist distances]               ;Distances are only calculated from sources
   
   ask turtles with [forager? = false] [set cores lput 40 cores]     ;For each camp-dweller, deposit one core of size 40, This is to ensure that turtles can work during the first few hundred ticks. 
   reset-ticks
end

to initialize                                             ;This sets the foragers to pretend that they have just deposited cobbles at the base camp.
  set cond1 false                                         ;These conditions are described in detail below. 
  set cond2 true
  set cond3 false
  set cond4 false
  set cond5 false
        
end

to go 
  
  ask turtles with [forager? = true or temp? = true ]     ;if you are a forager, or a temporary forager, perform the foraging procedure
        [forageprocedure]   
  ask turtles with [forager? = false] [camp-work ]        ;if you are not a forager, do work. 
  
  tick
  up-plot

   
end
 
to forageprocedure                                        ;this is where it gets complicated. 
   
  if cond1                                                ;If you are at the home patch and have not deposited.
    [ set var 1 
      if forager? = true 
      [deposit provision-self]]  
   
   if cond2                                               ;Those with cond2 just deposited, and now they set aim for another source     
     [ ifelse temp? = true                                ;If you are responding to a raw material shortage                
      [let potentials patches with [pcolor = white]  
       set target min-one-of potentials [dist] set var 2] ;identify the nearest material source and set that as your target.
      
      [set target one-of patches with [(pcolor = white) and (source? = true)] set var 2]]   ; otherwise, you are a regular forager, set target to a random source. 
   
   if sum pack > 16  [set color blue]                     ; this is to denote that the agent has material beyond the 16 threshold. 
   
   if cond3                  
         [ gototarget  work                               ; go towards target one step, and try to do work. 
          if sum pack < 16 [set color red]                ; In this case, all your cores are exhausted and you are unable to do work
          if patch-here = target [ set var 3 stock-up ]]  ; if you make it, stock and prepare to aim towards site
   
   if cond4 
         [ set target one-of patches with [pcolor = red] 
           set heading towards target set var 4]          ; aim to red (base). trigger cond 5
   
   if cond5 
         [ forward 1 
           work 
           set odometer odometer + 1                      ; track the distance travelled
           if patch-here = target [set var 5]]            ; go to red, trigger cond1 if this is the target. 
     
   setvariables                                           ;positioning this here, and using var to switch cond allows for all the turtle to so some part of the provision procedure independent of one another. Helps work to stay in same time scale
   
   
end

to setvariables
  if var = 1 [set cond2 true set cond1 false if temp? = true [set temp? false set forager? false set color gray]]   ;Sets the temporary forager back to camp-dweller after identifying shortage and going out to get more material.                 
  if var = 2 [set cond3 true set cond2 false]
  if var = 3 [set cond4 true set cond3 false]
  if var = 4 [set cond5 true set cond4 false]
  if var = 5 [set cond1 true set cond5 false]
  
end



to gototarget

  set heading towards target
  forward 1
  set odometer odometer + 1
  if patch-here = target 
         [if patch-here = white [set var 3 stock-up]
          if patch-here = patch 0 0 [set var 4]]
  work

end

to deposit
  let npack length pack  
  if npack > 1                                                       ; When npack = 1, loop is ended. 
         [let donationindex random (npack - 1 )           
          let donation item donationindex pack             
          ask patch-here 
                 [set cores lput donation cores ]                    ;sets the patch's list with an addition: the donation from the pack list
          
          set pack remove-item donationindex pack                    ;removes the donation from the pack. 
         
          deposit                                                    ;serves as a loop until npack = 1. 
          ] 
 end

to stock-up

  let cobblesize random-normal Csize 5
  set pack lput (int cobblesize) pack
  if sum pack < packsize          
         [stock-up]                                                   ;Another loop that serves to put stock a bit above prefered carrying capacity. 
  if sum pack > packsize                                              ;I don't think this is necessary, but when the turtle is fully stocked, it is probably over capacity, so it drops the smallest core. 
         [let minpack min pack
          let minindex position minpack pack  
          set pack remove-item minindex pack ]


end




to work
  
  set expectedwork expectedwork + .01                                  
  if length pack > 0                                                  ;Performed by foragers. if you have a core on you, do some work. 
[
let npack length pack
let decayedindex random npack
 let decayed item decayedindex pack
 if (mean pack) > 16
 [
 ifelse decayed < 15                                                  ;If what you pick to do work with is too small, drop it where you stand. then try working again. 
 [ 
  set expectedwork expectedwork + .01
  ;ask patch-here [set cores lput decayed cores]
   set pack remove-item decayedindex pack
   ifelse (pcolor = red) or (pcolor = white) [] [set pcolor yellow]
   work]
 [
 let decayedvalue decayed - decay                                     ;If the cobble is big enough, you reduce it by decay amount. 
 set pack replace-item decayedindex pack decayedvalue
 set workperformed workperformed + .01 
 set mobilework mobilework + .01
 ] ] 
  
  ] 
  

end



to camp-work
  
  set expectedwork expectedwork + .01
  if length cores >= 1 
  
  [let ncores length cores
    let recycledindex random ncores
    let recycled item recycledindex cores
       
    ifelse recycled > 15 
    [
    let recycledvalue recycled - decay
    set cores replace-item recycledindex cores recycledvalue
    set workperformed workperformed + .01
    set sedwork sedwork + .01
     ] 
    
    
    [ifelse max cores > 15 [camp-work]
      [set expectedwork expectedwork + .01
        if forecast = true [ ifelse max cores < (( %) * (random-normal (Csize) (.25 * Csize))) 
          [ set temp? true set forager? true
          forageprocedure] []] ]]]
  
   
                                                                      ;Here, we can give camp workers the ability to pop out and get nearby raw materials rather than wait for people to come back. 
  
  
end

to provision-self
  
  set expectedwork expectedwork + .01
  ifelse (temp? = false)                                              ;So, this setup allows for foragers to give themselves enough material to work with for their travels
  [                                                                   ; but temporary foragers do not bring anything with them, and do not do any work while moving to nearest source. 
  let ncores length cores
  let pickupindex random ncores
    if pickupindex > 0 [let pickup item pickupindex cores 
    set pack lput pickup pack 
    ask patch-here [set cores remove-item pickupindex cores]]
      
  ]
  []
  
end


to up-plot                                                             ; updates plots. 

  ask patch 0 0 [if length cores > 1 [set sd standard-deviation cores]]
  ask turtles with [color = gray] [set mpack []]
  ask turtles with [forager? = true] [if length pack > 1 and mean pack > 0 [set mpack mean pack]]
  ask patch 0 0 [let lcores? length cores
    set lcores lcores? ]
 if odometer > 2 and count turtles with [forager? = true] > 2 [set meantravel odometer / count turtles with [forager? = true]]
  
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
539
360
40
40
3.94
1
10
1
1
1
0
0
0
1
-40
40
-40
40
0
0
1
ticks
30.0

BUTTON
7
10
73
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
7
142
179
175
nofsources
nofsources
0
200
40
1
1
NIL
HORIZONTAL

SLIDER
8
175
180
208
nofturtles
nofturtles
0
100
40
1
1
NIL
HORIZONTAL

BUTTON
76
10
139
43
NIL
GO
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
10
45
73
78
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
6
248
178
281
decay
decay
0
4
4
.01
1
NIL
HORIZONTAL

SLIDER
6
281
178
314
Csize
Csize
40
80
80
5
1
NIL
HORIZONTAL

SLIDER
7
313
179
346
Packsize
Packsize
100
200
150
1
1
NIL
HORIZONTAL

PLOT
645
17
1022
257
Difference between actual work and potential work 
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot (expectedwork - workperformed)"

SLIDER
8
212
180
245
%
%
0
1
0.7
.05
1
NIL
HORIZONTAL

SWITCH
97
354
205
387
forecast
forecast
0
1
-1000

MONITOR
8
353
98
398
NIL
lcores
17
1
11

MONITOR
1
405
214
450
NIL
count turtles with [temp? = true]
17
1
11

MONITOR
549
61
641
106
NIL
workperformed
3
1
11

MONITOR
574
155
639
200
NIL
sedwork
3
1
11

MONITOR
556
108
641
153
NIL
mobilework
2
1
11

MONITOR
541
14
641
59
NIL
expectedwork
17
1
11

CHOOSER
73
45
211
90
rm-dist
rm-dist
1 2 3
1

SLIDER
8
108
180
141
radius
radius
0
500
15
1
1
NIL
HORIZONTAL

@#$#@#$#@
## ## ## WHAT IS IT?
This model presents a basic abstraction of the lithic raw material use and provisioning behavior of a group that inhabits a permanent base camp in an environment populated by some number of raw material sources. Here, forager agents constantly move to random raw material sources and pick up "cobbles" of lithic raw material until they can carry no more. They then return to the base camp and deposit these cobbles to repeat the process. During each tick, these turtles perform one unit of work, depleating their stock by some number. Camp dwellers, meanwhile, stay at the base camp and perform work. 
      The purpose of this model is to evaluate the effectiveness of different strategies of raw material provisioning at base camps in ensuring that all individuals have enough material with which to perform work.  The main unit of measurement here is the difference between potential work value, and actual work performed. The greater difference between these two values, the less effective the system is at providing turtles material they need to perform work. 


## ## ## HOW IT WORKS

    Go triggers two separate procedures, one for foragers, or temporary foragers (forageprocedure), and one for camp-dwellers (camp-work), then a tick, and the up-plot procedure. The forageprocedure is the most elaborate of the model. Here, turtles go in random order. The order of operations within the forageprocedure  are determined by a suite of IF statements, the conditions for which are triggered by set variables during the preceding operation. This ensures that each turtle performs one operation within the foragerprocedure independently per tick. 


## ## ## HOW TO USE IT

Most of the variability in the model is controlled through the global variables, which are listed here. Some may be modified using the sliders and toggles in the HUD. 

1. Sources. This value represents the number of raw material sources to be created during setup. This value is modified using a slider. 
2. Meantravel. This is the calculated mean travel distance. 
3. Odometer. THis tracks the distance each turtle travels and is used to calculate the mean distance travelled by all turtles per run. 
4. Distances. This is a list of the distances from those sources to the base camp
5. Lcores. This is set to the number of cores at the base camp during the up-plot procedure. 
4. Workperformed. Each time a turtle has enough raw material to perform work (i.e. that performing work is successful), .01 is added to this variable. 
5. Mobilework. Each time a foraging turtle has enough raw material to perform work, .01 is added to this variable.
6. Sedwork. Each time a camp dweller has enough raw material to perform work, .01 is added to this variable.
7. Expectedwork. Each time a turtle could possibly have performed work, .01 is added to this variable, regardless of whether there was enough raw material to perform that work. 
8.  Nofturtles. This variable is altered by a slider, and denotes the number of turtles to be created during the setup procedure.
11. %. Denotes the proportion of turtles that are to be set to camp dwellers. 
12. Decay. This  is the measure of how much is subtracted from a cobble per unit of work performed. 
13. Csize. This value serves as the mean of the normal distribution from which turtles draw new cobble sizes from source patches. Simulations were run keeping cobble size at 80. 
14. Packsize.  This represents the carrying capacity of turtles. Turtles that draw cobbles from sources will draw values until the sum of those values exceeds this value. 
15. rm-dist. Variable that indicates whether sources will be created randomly, or within or outside a given radius. 
16. Forecast. True or false variable that triggers the ability of camp dwellers to identify when available core stocks are low, and change their behavior to temporary foraging. 
17. Radius. Used for establishing distributions of raw material sources. 



## ## ## THINGS TO NOTICE

1. The difference between the work done, and potential work done by agents increases and decreases along with variation in decay.

2. The simple addition of adaptive responses to raw material shortages at the base camp increases the work output in most configurations.

3. In some configurations, the number of cores left at the base camp never really grows. In those cases, foragers are taking that material to provision themselves before moving off. 


## ## ## ADDITIONS

Can the agents behave in such a way that they would not need smaller degrees of decay in order to perform work successfully, even in conditions that woudl otherwise strain raw material stocks? Changes to the ability of agents to perceive the state of the raw material stock at the base camp and some heterogeneity in the decision making of agents when it comes to responding to stock crashes will likely help.


## ## ## RELATED MODELS

While this model focuses on work output given differences in core reduction efficiency, Barton and Riel-Salvatore (2014) more closely examine ways to reproduce archaeological records in netlogo, which may be compared to real assemblages. Janssen and Oestmo (2013) replicated Brantingham's 2003 model which was used to argue that random models could produce some of the patterns observed in the archaeological record. These are some of the few agent based models that deal specifically with prehistoric lithic technology.

Barton, C Michael, Riel-Salvatore, Julien (2014, September 3). "Formation of Lithic Assemblages v. 1" (Version 1). CoMSES Computational Model Library. Retrieved from: http://hdl.handle.net/2286.0/oabm.3949

Janssen, Marco A., Oestmo, Simen (2013, September 30). "A Neutral Model of Stone Raw Material Procurement" (Version 1). CoMSES Computational Model Library. Retrieved from: http://hdl.handle.net/2286.0/oabm:3957


## ## ## CREDITS AND REFERENCES
Please see the ODD protocol for this model on Openabm.org for more detailed information.
Email the author if you have any questions (jnpaige@asu.edu)

Copyright Jonathan Paige (Arizona State University)

This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/3.0/ or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="5" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>m</metric>
    <metric>sd</metric>
    <metric>mean distances</metric>
    <enumeratedValueSet variable="Csize">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decay">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Close?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Packsize">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nofturtles">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nofsources">
      <value value="2"/>
    </enumeratedValueSet>
    <steppedValueSet variable="%" first="0.1" step="0.1" last="0.9"/>
  </experiment>
  <experiment name="EXP RANGE FOR WORK, RANGE FOR  PACKSIZE 2.0 march 2015" repetitions="8" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="4000"/>
    <metric>expectedwork - workperformed</metric>
    <metric>expectedwork</metric>
    <metric>workperformed</metric>
    <metric>mobilework</metric>
    <metric>sedwork</metric>
    <metric>meantravel</metric>
    <metric>nofturtles</metric>
    <metric>nofsources</metric>
    <metric>radius</metric>
    <metric>%</metric>
    <metric>decay</metric>
    <metric>packsize</metric>
    <enumeratedValueSet variable="rm-dist">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="radius" first="15" step="10" last="35"/>
    <enumeratedValueSet variable="Csize">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forecast">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nofturtles">
      <value value="40"/>
    </enumeratedValueSet>
    <steppedValueSet variable="%" first="0.1" step="0.1" last="0.9"/>
    <enumeratedValueSet variable="nofsources">
      <value value="40"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Packsize" first="100" step="50" last="200"/>
    <steppedValueSet variable="decay" first="0.5" step="0.5" last="3"/>
  </experiment>
  <experiment name="EXP RANGE FOR WORK, RANGE FOR  PACKSIZE" repetitions="5" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="750"/>
    <metric>expectedwork - workperformed</metric>
    <metric>lcores</metric>
    <metric>expectedwork</metric>
    <metric>workperformed</metric>
    <metric>mobilework</metric>
    <metric>sedwork</metric>
    <metric>mean distances</metric>
    <enumeratedValueSet variable="Close?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Csize">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forecast">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nofturtles">
      <value value="40"/>
    </enumeratedValueSet>
    <steppedValueSet variable="%" first="0" step="0.1" last="1"/>
    <enumeratedValueSet variable="selfprovamount">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="nofsources" first="20" step="20" last="100"/>
    <steppedValueSet variable="Packsize" first="100" step="50" last="200"/>
    <steppedValueSet variable="decay" first="0.5" step="0.5" last="3"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
